# Faas Supervisor

[![Build Status](https://travis-ci.org/grycap/faas-supervisor.svg)](https://travis-ci.org/grycap/faas-supervisor) [![PyPi version](https://img.shields.io/pypi/v/faas-supervisor.svg)](https://pypi.org/project/faas-supervisor/) [![License](https://img.shields.io/badge/license-Apache%202-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Input / Output data manager for FaaS functions.
Works in different cloud environments and allows different data providers.

Python package available at Pypi with the name **faas-supervisor**.
